@@ -14,7 +14,7 @@
 // You should have received a copy of the GNU General Public License
 // along with the snarkVM library. If not, see <https://www.gnu.org/licenses/>.
 
-use crate::{impl_bytes, *};
+use crate::{impl_bytes, BTreeMap, *};
 use core::ops::{Add, AddAssign};
 use snarkvm_errors::serialization::SerializationError;
 use snarkvm_models::curves::{AffineCurve, PairingCurve, PairingEngine, PrimeField, ProjectiveCurve, Zero};
@@ -23,7 +23,6 @@ use snarkvm_utilities::{
     error,
     serialize::{CanonicalDeserialize, CanonicalSerialize},
 };
-use std::collections::BTreeMap;
 
 /// `UniversalParams` are the universal parameters for the KZG10 scheme.
 #[derive(Derivative)]
