@@ -14,7 +14,7 @@
 // You should have received a copy of the GNU General Public License
 // along with the snarkVM library. If not, see <https://www.gnu.org/licenses/>.
 
-use crate::{impl_bytes, kzg10, PCCommitterKey, PCVerifierKey, Vec};
+use crate::{impl_bytes, kzg10, BTreeMap, PCCommitterKey, PCVerifierKey, Vec};
 use snarkvm_errors::serialization::SerializationError;
 use snarkvm_models::curves::{PairingCurve, PairingEngine};
 use snarkvm_utilities::{
@@ -22,7 +22,6 @@ use snarkvm_utilities::{
     error,
     serialize::*,
 };
-use std::collections::BTreeMap;
 
 /// `UniversalParams` are the universal parameters for the KZG10 scheme.
 pub type UniversalParams<E> = kzg10::UniversalParams<E>;
